@@ -4,19 +4,19 @@ require 'active_support'
 dir = File.expand_path(File.join(File.dirname(__FILE__), '..', 'lib'))
 require File.join(dir, 'httparty')
 require 'pp'
-config = YAML::load(File.read(File.join(ENV['HOME'], '.aaws')))
+config = YAML.load(File.read(File.join(ENV['HOME'], '.aaws')))
 
 module AAWS
   class Book
     include HTTParty
     base_uri 'http://ecs.amazonaws.com'
-    default_params :Service => 'AWSECommerceService', :Operation => 'ItemSearch', :SearchIndex => 'Books'
+    default_params Service: 'AWSECommerceService', Operation: 'ItemSearch', SearchIndex: 'Books'
 
     def initialize(key)
-      self.class.default_params :AWSAccessKeyId => key
+      self.class.default_params AWSAccessKeyId: key
     end
 
-    def search(options={})
+    def search(options = {})
       raise ArgumentError, 'You must search for something' if options[:query].blank?
 
       # amazon uses nasty camelized query params
@@ -29,4 +29,4 @@ module AAWS
 end
 
 aaws = AAWS::Book.new(config[:access_key])
-pp aaws.search(:query => {:title => 'Ruby On Rails'})
+pp aaws.search(query: { title: 'Ruby On Rails' })
