@@ -1,4 +1,4 @@
-require File.expand_path(File.join(File.dirname(__FILE__), '..', 'spec_helper'))
+require 'spec_helper'
 
 RSpec.describe HTTParty::Response do
   before do
@@ -39,10 +39,16 @@ RSpec.describe HTTParty::Response do
     it "should set code" do
       expect(@response.code).to eq(@response_object.code)
     end
-
+        
     it "should set code as an Integer" do
       expect(@response.code).to be_a(Integer)
     end
+    
+    it "should set http_version" do
+      unparseable_body = lambda { raise "Unparseable" }
+      unparseable_response = HTTParty::Response.new(@request_object, @response_object, unparseable_body)
+      expect(unparseable_response.http_version).to eq(@response_object.http_version)
+    end
 
     context 'when raise_on is supplied' do
       let(:request) { HTTParty::Request.new(Net::HTTP::Get, '/', raise_on: [404]) }
@@ -78,11 +84,11 @@ RSpec.describe HTTParty::Response do
     }.to raise_error(NameError, /HTTParty\:\:Response/)
   end
 
-  it 'does raise an error about itself when invoking a method that does not exist' do 
+  it 'does raise an error about itself when invoking a method that does not exist' do
     expect {
       HTTParty::Response.new(@request_object, @response_object, @parsed_response).qux
     }.to raise_error(NoMethodError, /HTTParty\:\:Response/)
-  end 
+  end
 
   it "returns response headers" do
     response = HTTParty::Response.new(@request_object, @response_object, @parsed_response)
@@ -131,21 +137,21 @@ RSpec.describe HTTParty::Response do
 
   context 'response is array' do
     let(:response_value) { [{'foo' => 'bar'}, {'foo' => 'baz'}] }
-    let(:response) { HTTParty::Response.new(@request_object, @response_object, lambda { response_value }) } 
-    it "should be able to iterate" do 
+    let(:response) { HTTParty::Response.new(@request_object, @response_object, lambda { response_value }) }
+    it "should be able to iterate" do
       expect(response.size).to eq(2)
       expect {
         response.each { |item| }
       }.to_not raise_error
     end
 
-    it 'should respond to array methods' do       
-      expect(response).to respond_to(:bsearch, :compact, :cycle, :delete, :each, :flatten, :flatten!, :compact, :join)    
+    it 'should respond to array methods' do
+      expect(response).to respond_to(:bsearch, :compact, :cycle, :delete, :each, :flatten, :flatten!, :compact, :join)
     end
 
     it 'should equal the string response object body' do
-      expect(response.to_s).to eq(@response_object.body.to_s)    
-    end    
+      expect(response.to_s).to eq(@response_object.body.to_s)
+    end
 
     it 'should display the same as an array' do
       a = StringIO.new
@@ -153,7 +159,7 @@ RSpec.describe HTTParty::Response do
       response_value.display(b)
       response.display(a)
 
-      expect(a.string).to eq(b.string)    
+      expect(a.string).to eq(b.string)
     end
   end
 
@@ -282,6 +288,15 @@ RSpec.describe HTTParty::Response do
         SPECIFIC_CODES[:multiple_choices?] = Net::HTTPMultipleChoices
       end
 
+      # Ruby 2.6, those status codes have been updated.
+      if RUBY_VERSION >= "2.6.0" && ::RUBY_PLATFORM != "java"
+        SPECIFIC_CODES[:gateway_timeout?]       = Net::HTTPGatewayTimeout
+        SPECIFIC_CODES[:payload_too_large?]     = Net::HTTPPayloadTooLarge
+        SPECIFIC_CODES[:request_timeout?]       = Net::HTTPRequestTimeout
+        SPECIFIC_CODES[:uri_too_long?]          = Net::HTTPURITooLong
+        SPECIFIC_CODES[:range_not_satisfiable?] = Net::HTTPRangeNotSatisfiable
+      end
+
       SPECIFIC_CODES.each do |method, klass|
         it "responds to #{method}" do
           net_response = response_mock(klass)
@@ -294,27 +309,27 @@ RSpec.describe HTTParty::Response do
 
   describe "headers" do
     let (:empty_headers) { HTTParty::Response::Headers.new }
-    let (:some_headers_hash) do 
+    let (:some_headers_hash) do
       {'Cookie' => 'bob',
       'Content-Encoding' => 'meow'}
-    end 
-    let (:some_headers) do 
-       HTTParty::Response::Headers.new.tap do |h|
-         some_headers_hash.each_pair do |k,v|
-           h[k] = v
-         end
+    end
+    let (:some_headers) do
+      HTTParty::Response::Headers.new.tap do |h|
+        some_headers_hash.each_pair do |k,v|
+          h[k] = v
+        end
       end
     end
-    it "can initialize without headers" do 
+    it "can initialize without headers" do
       expect(empty_headers).to eq({})
     end
 
     it 'always equals itself' do
-      expect(empty_headers).to eq(empty_headers) 
+      expect(empty_headers).to eq(empty_headers)
       expect(some_headers).to eq(some_headers)
     end
 
-    it 'does not equal itself when not equivalent' do 
+    it 'does not equal itself when not equivalent' do
       expect(empty_headers).to_not eq(some_headers)
     end
 
@@ -344,4 +359,16 @@ RSpec.describe HTTParty::Response do
       expect(inspect).to include("content-length")
     end
   end
+
+  describe 'marshalling' do
+    before { RSpec::Mocks.space.proxy_for(@response_object).remove_stub(:body) }
+
+    specify do
+      marshalled = Marshal.load(Marshal.dump(@response))
+
+      expect(marshalled.headers).to eq @response.headers
+      expect(marshalled.body).to eq @response.body
+      expect(marshalled.code).to eq @response.code
+    end
+  end
 end
