@@ -1,13 +1,13 @@
-require File.expand_path(File.join(File.dirname(__FILE__), '..', 'spec_helper'))
+require 'spec_helper'
 
 RSpec.describe HTTParty::Request do
   context "SSL certificate verification" do
     before do
-      WebMock.allow_net_connect!
+      WebMock.disable!
     end
 
     after do
-      WebMock.disable_net_connect!
+      WebMock.enable!
     end
 
     it "should fail when no trusted CA list is specified, by default" do
@@ -70,5 +70,13 @@ RSpec.describe HTTParty::Request do
         ssl_verify_test(:ssl_ca_path, ".", "bogushost.crt")
       end.to raise_error(OpenSSL::SSL::SSLError)
     end
+
+    it "should provide the certificate used by the server via peer_cert" do
+      peer_cert = nil
+      ssl_verify_test(:ssl_ca_file, "ca.crt", "server.crt") do |response|
+        peer_cert ||= response.connection.peer_cert
+      end
+      expect(peer_cert).to be_a OpenSSL::X509::Certificate
+    end
   end
 end
