@@ -1,5 +1,6 @@
 require "simplecov"
 SimpleCov.start
+require 'pry'
 
 require "httparty"
 require 'webmock/rspec'
@@ -37,6 +38,11 @@ RSpec.configure do |config|
 
   config.order = :random
 
+  config.before(:each) do
+    # Reset default_cert_store cache
+    HTTParty::ConnectionAdapter.instance_variable_set(:@default_cert_store, nil)
+  end
+
   Kernel.srand config.seed
 end
 
